#!/usr/bin/env python
# -*- coding: utf8 -*-

# http://flask.pocoo.org/docs/0.10/testing/#testing

import os
import flaskr
import unittest
import tempfile

class FlaskrTestCase( unittest.TestCase ):
    def setUp( self ):
        # mkstemp() return a tuple with (os_level_handle, full_filename)
        # mkstemp() is responsible of the file deletion when file is closed
        self.db_fd, flaskr.app.config['DATABASE'] = tempfile.mkstemp()
        
        # Avoids trapping error and get more détails in the unit test 
        flaskr.app.config['TESTING'] = True
        
        # Will keep the cookie for us.
        self.app = flaskr.app.test_client()
        
        flaskr.init_db()
        
    def tearDown( self ):
        # close the physical file attached to the database
        os.close( self.db_fd )
        # delete the file (unlink is traditional unix name for delete)
        os.unlink( flaskr.app.config['DATABASE'] )
        
    # The majority of the functions are reserved to administrative tasks...
    # So we need a way to log-in the app (the app.test_client will take care
    #    of the cookies for us)
    def do_login(self, user, passwd ):
       return self.app.post('/login', \
           data = dict(username=user,password=passwd), \
           follow_redirects=True )
           
    def do_logout( self ):
        return self.app.get('/logout', follow_redirects=True )
    
    
    def test_empty_db(self):
        # execute the get and return a response_class object
        rv = self.app.get('/')
        assert 'aucune entrée!!!' in rv.data

    def test_login_logout(self):
        rv = self.do_login( 'admin', 'default' )
        assert 'You are logged in' in rv.data
        rv = self.do_logout()
        assert 'you are logged out' in rv.data
        rv = self.do_login('adminx', 'default' )
        assert 'Invalid username' in rv.data   
        rv = self.do_login('admin', 'zz')
        assert 'Invalid password' in rv.data     
            
    def test_messages( self ):
        rv = self.do_login( 'admin','default' )
        rv = self.app.post( '/add', data=dict( \
          title='<hello>', \
          text='<strong>HTML</strong> allowed here' \
          ), follow_redirects=True )
        assert 'aucune entréee!!!' not in rv.data
        assert '&lt;hello&gt;' in rv.data
        assert '<strong>HTML</strong>' in rv.data
        
if __name__ == '__main__':
     unittest.main()